package pl.ivend.pg2oracle;

import pl.ivend.pg2oracle.work.Convert;
import pl.ivend.pg2oracle.work.ConvertArgs;

public final class Main {

	private static final String PO = "-po";
	private static final String OP = "-op";

	private static final String A = "-a";

	private static final String S = "-s";
	private static final String SQ = "-sq";
	private static final String USQ = "-usq";
	private static final String T = "-t";
	private static final String V = "-v";
	private static final String D = "-d";
	private static final String P = "-p";
	private static final String C = "-c";
	private static final String TR = "-tr";

	private static final String SS = "-ss:";
	private static final String ST = "-st:";

	public static void main(String[] args) {

		if (args.length == 0) {
			printInfo();
			return;
		}

		Config.load();
		Convert convert = new Convert(prepareConvertArgs(args), Config.getPref());

		if (isArg(args, PO)) {
			convert.postgresToOracle();
		}
		if (isArg(args, OP)) {
			convert.oracleToPostgres();
		}

	}

	private static boolean isArg(String[] args, String arg) {
		for (String a : args) {
			if (arg.equals(a)) {
				return true;
			}
		}
		return false;
	}

	private static String getValueArg(String[] args, String arg) {
		for (String a : args) {
			if (a.startsWith(arg)) {
				return a;
			}
		}
		return null;
	}

	private static String[] convertString(String valueArg) {
		String[] tokens = valueArg.split(":");
		if (tokens.length > 0) {
			return tokens[1].split(",");
		}
		return null;
	}

	private static String[] prepareSchemaNames(String[] args) {
		String valueArg = getValueArg(args, SS);
		if (valueArg != null) {
			return convertString(valueArg);
		}
		return null;
	}

	private static String[] prepareTableNames(String[] args) {
		String valueArg = getValueArg(args, ST);
		if (valueArg != null) {
			return convertString(valueArg);
		}
		return null;
	}

	private static ConvertArgs prepareConvertArgs(String[] args) {
		ConvertArgs convertArgs = new ConvertArgs();
		boolean isAll = isArg(args, A);
		convertArgs.setSchemas(isAll || isArg(args, S));
		convertArgs.setSequences(isAll || isArg(args, SQ));
		convertArgs.setTables(isAll || isArg(args, T));
		convertArgs.setViews(isAll || isArg(args, V));
		convertArgs.setDatas(isAll || isArg(args, D));
		convertArgs.setPrimaryKeys(isAll || isArg(args, P));
		convertArgs.setConstraints(isAll || isArg(args, C));
		// convertArgs.setTriggers(isAll || isArg(args, TR));
		convertArgs.setSchemaNames(prepareSchemaNames(args));
		convertArgs.setTableNames(prepareTableNames(args));
		convertArgs.setSequencesUpdate(isArg(args, USQ));
		return convertArgs;
	}

	private static void printInfo() {
		System.out.println("Program należy wywołać z parametrami");
		System.out.println("====================================");
		System.out.println("-po => konwersja z postgresql do oracle");
		System.out.println("-op => konwersja z oracle do postgresql");
		System.out.println("-a  => konwersja całej bazy (tabele, klucze, dane w tabelach)");
		System.out.println("-s  => konwersja schematów");
		System.out.println("-sq => konwersja sekwencji");
		System.out.println("-t  => konwersja tabel");
		System.out.println("-v  => konwersja widoków");
		System.out.println("-d  => konwersja danych w tabelach");
		System.out.println("-p  => konwersja kluczym głównych tabel");
		System.out.println("-c  => konwersja powiązań pomiędzy tabelami");
		// System.out.println("-tr => konwersja trigerów");
		System.out.println("-ss => przygotowanie nazw schematów");
		System.out.println("-st => przygotowanie nazw tabel");
		System.out.println("-usq => aktualizacja istniejących sekwencji");
	}

}
