package pl.ivend.pg2oracle.work.util;

import pl.ivend.pg2oracle.work.ConstraintType;
import pl.ivend.pg2oracle.work.DatabaseType;
import pl.ivend.pg2oracle.work.exception.DatabaseTypeException;

public final class ConstraintUtil {

	private static final String POSTGRES_PRIMARY_KEY = "PRIMARY KEY";
	private static final String ORACLE_PRIMARY_KEY = "P";

	private ConstraintUtil() {
		// TODO Auto-generated constructor stub
	}

	public static String getPrimaryKey(DatabaseType databaseType) {
		switch (databaseType) {
		case POSTGRES:
			return POSTGRES_PRIMARY_KEY;
		case ORACLE:
			return ORACLE_PRIMARY_KEY;
		}
		throw new DatabaseTypeException(databaseType);
	}

	public static ConstraintType convString(String typ, DatabaseType databaseType) {
		switch (databaseType) {
		case POSTGRES:
			return convPostgresString(typ);
		case ORACLE:
			return convOracleString(typ);
		}
		throw new DatabaseTypeException(databaseType);
	}

	private static ConstraintType convPostgresString(String typ) {
		if (POSTGRES_PRIMARY_KEY.equals(typ)) {
			return ConstraintType.PKEY;
		} else if ("FOREIGN KEY".equals(typ)) {
			return ConstraintType.FKEY;
		} else if ("UNIQUE".equals(typ)) {
			return ConstraintType.UNIQUE;
		} else if ("CHECK".equals(typ)) {
			return ConstraintType.TCHECK;
		} else {
			return ConstraintType.UNKNOWN;
		}
	}

	private static ConstraintType convOracleString(String typ) {
		if (ORACLE_PRIMARY_KEY.equals(typ)) {
			return ConstraintType.PKEY;
		} else if ("R".equals(typ)) {
			return ConstraintType.FKEY;
		} else if ("U".equals(typ)) {
			return ConstraintType.UNIQUE;
		} else if ("C".equals(typ)) {
			return ConstraintType.TCHECK;
		} else if ("V".equals(typ)) {
			return ConstraintType.VCHECK;
		} else if ("O".equals(typ)) {
			return ConstraintType.READONLY;
		} else {
			return ConstraintType.UNKNOWN;
		}
	}

}
